@@ -33,6 +33,7 @@ Implementations for Python 2.
 import ConfigParser as configparser  # noqa
 import json
 import subprocess
+import time
 import urllib2 as std_urllib  # noqa
 from collections import Mapping, OrderedDict  # noqa
 from HTMLParser import HTMLParser  # noqa
@@ -55,7 +56,25 @@ json_loads = json.loads
 
 def subprocess_popen_text(cmd, **kwargs):
     """Call subprocess.Popen with specified named arguments."""
-    return subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, **kwargs)
+    kwargs.setdefault('stderr', subprocess.PIPE)
+    return subprocess.Popen(cmd, stdout=subprocess.PIPE, **kwargs)
+
+
+def subprocess_terminate(proc, timeout):
+    """Terminate the subprocess if it hasn't finished after the given timeout"""
+    res = None
+    for pipe in (proc.stdout, proc.stderr, proc.stdin):
+        if pipe:
+            pipe.close()
+    while timeout > 0:
+        res = proc.poll()
+        if res is not None:
+            break
+        delay = min(timeout, 0.1)
+        time.sleep(delay)
+        timeout -= delay
+    if res is None:
+        proc.terminate()
 
 
 def raise_with_traceback(exception_class, message, traceback):
