@@ -69,7 +69,19 @@ def json_loads(body):
 def subprocess_popen_text(cmd, **kwargs):
     """Call subprocess.Popen in text mode with specified named arguments."""
     # open stdout/stderr in text mode in Popen when using Python 3
-    return subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, **kwargs)
+    kwargs.setdefault('stderr', subprocess.PIPE)
+    return subprocess.Popen(cmd, stdout=subprocess.PIPE, universal_newlines=True, **kwargs)
+
+
+def subprocess_terminate(proc, timeout):
+    """Terminate the subprocess if it hasn't finished after the given timeout"""
+    try:
+        proc.communicate(timeout=timeout)
+    except subprocess.TimeoutExpired:
+        for pipe in (proc.stdout, proc.stderr, proc.stdin):
+            if pipe:
+                pipe.close()
+        proc.terminate()
 
 
 def raise_with_traceback(exception_class, message, traceback):
