@@ -1,5 +1,5 @@
 # #
-# Copyright 2013-2021 Ghent University
+# Copyright 2013-2022 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -40,7 +40,8 @@ import easybuild.tools.options as eboptions
 from easybuild.tools import run
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.config import build_option, build_path, get_build_log_path, get_log_filename, get_repositorypath
-from easybuild.tools.config import install_path, log_file_format, log_path, source_paths, update_build_option
+from easybuild.tools.config import install_path, log_file_format, log_path, source_paths
+from easybuild.tools.config import update_build_option, update_build_options
 from easybuild.tools.config import BuildOptions, ConfigurationVariables
 from easybuild.tools.config import DEFAULT_PATH_SUBDIRS, init_build_options
 from easybuild.tools.filetools import copy_dir, mkdir, write_file
@@ -302,7 +303,7 @@ class EasyBuildConfigTest(EnhancedTestCase):
         self.assertEqual(install_path('mod'), installpath_modules),  # via config file
         self.assertEqual(source_paths(), [testpath2])  # via command line
         self.assertEqual(build_path(), testpath1)  # via config file
-        self.assertEqual(get_repositorypath(), (os.path.join(topdir, 'ebfiles_repo'), 'somesubdir'))  # via config file
+        self.assertEqual(get_repositorypath(), [os.path.join(topdir, 'ebfiles_repo'), 'somesubdir'])  # via config file
 
         # hardcoded first entry
         self.assertEqual(options.robot_paths[0], '/tmp/foo')
@@ -680,9 +681,48 @@ class EasyBuildConfigTest(EnhancedTestCase):
     def test_update_build_option(self):
         """Test updating of a build option."""
         self.assertEqual(build_option('banned_linked_shared_libs'), None)
-
-        update_build_option('banned_linked_shared_libs', '/usr/lib64/libssl.so.1.1')
+        orig_banned_linked_shared_libs = update_build_option('banned_linked_shared_libs', '/usr/lib64/libssl.so.1.1')
         self.assertEqual(build_option('banned_linked_shared_libs'), '/usr/lib64/libssl.so.1.1')
+        self.assertEqual(orig_banned_linked_shared_libs, None)
+
+        self.assertTrue(build_option('cleanup_builddir'))
+        orig_cleanup_builddir = update_build_option('cleanup_builddir', False)
+        self.assertFalse(build_option('cleanup_builddir'))
+        self.assertTrue(orig_cleanup_builddir)
+
+        self.assertEqual(build_option('pr_target_account'), 'easybuilders')
+        orig_pr_target_account = update_build_option('pr_target_account', 'test_pr_target_account')
+        self.assertEqual(build_option('pr_target_account'), 'test_pr_target_account')
+        self.assertEqual(orig_pr_target_account, 'easybuilders')
+
+    def test_update_build_options(self):
+        """Test updating of a dictionary of build options."""
+        # Check if original defaults are as expected:
+        self.assertEqual(build_option('banned_linked_shared_libs'), None)
+        self.assertEqual(build_option('filter_env_vars'), None)
+        self.assertTrue(build_option('cleanup_builddir'))
+        self.assertEqual(build_option('pr_target_account'), 'easybuilders')
+
+        # Update build options based on dictionary
+        new_opt_dict = {
+            'banned_linked_shared_libs': '/usr/lib64/libssl.so.1.1',
+            'filter_env_vars': 'LD_LIBRARY_PATH',
+            'cleanup_builddir': False,
+            'pr_target_account': 'test_pr_target_account',
+        }
+        original_opt_dict = update_build_options(new_opt_dict)
+        self.assertEqual(build_option('banned_linked_shared_libs'), '/usr/lib64/libssl.so.1.1')
+        self.assertEqual(build_option('filter_env_vars'), 'LD_LIBRARY_PATH')
+        self.assertFalse(build_option('cleanup_builddir'))
+        self.assertEqual(build_option('pr_target_account'), 'test_pr_target_account')
+
+        # Check the returned dictionary by simply restoring the variables and checking if the build
+        # options have their original values again
+        update_build_options(original_opt_dict)
+        self.assertEqual(build_option('banned_linked_shared_libs'), None)
+        self.assertEqual(build_option('filter_env_vars'), None)
+        self.assertTrue(build_option('cleanup_builddir'))
+        self.assertEqual(build_option('pr_target_account'), 'easybuilders')
 
 
 def suite():
